@@ -1,6 +1,7 @@
 /*
     This file is part of the KDE project
     SPDX-FileCopyrightText: 2004-2014 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2024 Méven Car <meven@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,8 +10,6 @@
 
 #include <QHash>
 #include <QList>
-#include <QMap>
-#include <QVector>
 
 #include <kio/global.h> // filesize_t
 #include <kio/udsentry.h>
@@ -31,177 +30,40 @@ class UdsEntryBenchmark : public QObject
 public:
     UdsEntryBenchmark()
         : nameStr(QStringLiteral("name"))
+        , groupStr(QStringLiteral("group"))
         , now(QDateTime::currentDateTime())
         , now_time_t(now.toSecsSinceEpoch())
     {
     }
 private Q_SLOTS:
-    void testKDE3Slave();
-    void testKDE3App();
-    void testHashVariantSlave();
-    void testHashVariantApp();
-    void testHashStructSlave();
-    void testHashStructApp();
-    void testMapStructSlave();
-    void testMapStructApp();
-    void testTwoVectorsSlaveFill();
-    void testTwoVectorsSlaveCompare();
-    void testTwoVectorsApp();
-    void testAnotherSlaveFill();
-    void testAnotherSlaveCompare();
-    void testAnotherApp();
-    void testAnotherV2SlaveFill();
-    void testAnotherV2SlaveCompare();
-    void testAnotherV2App();
 
-private:
+    void testAnotherFill();
+    void testTwoVectorKindEntryFill();
+    void testAnotherV2Fill();
+    void testTwoVectorsFill();
+    void testUDSEntryHSFill();
+
+    void testAnotherCompare();
+    void testTwoVectorKindEntryCompare();
+    void testAnotherV2Compare();
+    void testTwoVectorsCompare();
+    void testUDSEntryHSCompare();
+
+    void testAnotherApp();
+    void testTwoVectorKindEntryApp();
+    void testAnotherV2App();
+    void testTwoVectorsApp();
+    void testUDSEntryHSApp();
+
+    void testspaceUsed();
+
+public:
     const QString nameStr;
+    const QString groupStr;
     const QDateTime now;
     const time_t now_time_t;
 };
 
-class OldUDSAtom
-{
-public:
-    QString m_str;
-    long long m_long;
-    unsigned int m_uds;
-};
-typedef QList<OldUDSAtom> OldUDSEntry; // well it was a QValueList :)
-
-static void fillOldUDSEntry(OldUDSEntry &entry, time_t now_time_t, const QString &nameStr)
-{
-    OldUDSAtom atom;
-    atom.m_uds = KIO::UDSEntry::UDS_NAME;
-    atom.m_str = nameStr;
-    entry.append(atom);
-    atom.m_uds = KIO::UDSEntry::UDS_SIZE;
-    atom.m_long = 123456ULL;
-    entry.append(atom);
-    atom.m_uds = KIO::UDSEntry::UDS_MODIFICATION_TIME;
-    atom.m_long = now_time_t;
-    entry.append(atom);
-    atom.m_uds = KIO::UDSEntry::UDS_ACCESS_TIME;
-    atom.m_long = now_time_t;
-    entry.append(atom);
-    atom.m_uds = KIO::UDSEntry::UDS_FILE_TYPE;
-    atom.m_long = S_IFREG;
-    entry.append(atom);
-    atom.m_uds = KIO::UDSEntry::UDS_ACCESS;
-    atom.m_long = 0644;
-    entry.append(atom);
-    atom.m_uds = KIO::UDSEntry::UDS_USER;
-    atom.m_str = nameStr;
-    entry.append(atom);
-    atom.m_uds = KIO::UDSEntry::UDS_GROUP;
-    atom.m_str = nameStr;
-    entry.append(atom);
-}
-
-void UdsEntryBenchmark::testKDE3Slave()
-{
-    QBENCHMARK {
-        OldUDSEntry entry;
-        fillOldUDSEntry(entry, now_time_t, nameStr);
-        QCOMPARE(entry.count(), 8);
-    }
-}
-
-void UdsEntryBenchmark::testKDE3App()
-{
-    OldUDSEntry entry;
-    fillOldUDSEntry(entry, now_time_t, nameStr);
-
-    QString displayName;
-    KIO::filesize_t size;
-    QString url;
-
-    QBENCHMARK {
-        OldUDSEntry::ConstIterator it2 = entry.constBegin();
-        for (; it2 != entry.constEnd(); it2++) {
-            switch ((*it2).m_uds) {
-            case KIO::UDSEntry::UDS_NAME:
-                displayName = (*it2).m_str;
-                break;
-            case KIO::UDSEntry::UDS_URL:
-                url = (*it2).m_str;
-                break;
-            case KIO::UDSEntry::UDS_SIZE:
-                size = (*it2).m_long;
-                break;
-            }
-        }
-        QCOMPARE(size, 123456ULL);
-        QCOMPARE(displayName, QStringLiteral("name"));
-        QVERIFY(url.isEmpty());
-    }
-}
-
-// QHash or QMap? doesn't seem to make much difference.
-typedef QHash<uint, QVariant> UDSEntryHV;
-
-// This uses QDateTime instead of time_t
-static void fillUDSEntryHV(UDSEntryHV &entry, const QDateTime &now, const QString &nameStr)
-{
-    entry.reserve(8);
-    entry.insert(KIO::UDSEntry::UDS_NAME, nameStr);
-    // we might need a method to make sure people use unsigned long long
-    entry.insert(KIO::UDSEntry::UDS_SIZE, 123456ULL);
-    entry.insert(KIO::UDSEntry::UDS_MODIFICATION_TIME, now);
-    entry.insert(KIO::UDSEntry::UDS_ACCESS_TIME, now);
-    entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
-    entry.insert(KIO::UDSEntry::UDS_ACCESS, 0644);
-    entry.insert(KIO::UDSEntry::UDS_USER, nameStr);
-    entry.insert(KIO::UDSEntry::UDS_GROUP, nameStr);
-}
-
-void UdsEntryBenchmark::testHashVariantSlave()
-{
-    const QDateTime now = QDateTime::currentDateTime();
-    QBENCHMARK {
-        UDSEntryHV entry;
-        fillUDSEntryHV(entry, now, nameStr);
-        QCOMPARE(entry.count(), 8);
-    }
-}
-
-void UdsEntryBenchmark::testHashVariantApp()
-{
-    // Normally the code would look like this, but let's change it to time it like the old api
-    /*
-       QString displayName = entry.value( KIO::UDSEntry::UDS_NAME ).toString();
-       QUrl url = entry.value( KIO::UDSEntry::UDS_URL ).toString();
-       KIO::filesize_t size = entry.value( KIO::UDSEntry::UDS_SIZE ).toULongLong();
-     */
-    UDSEntryHV entry;
-    fillUDSEntryHV(entry, now, nameStr);
-
-    QString displayName;
-    KIO::filesize_t size;
-    QString url;
-
-    QBENCHMARK {
-        // For a field that we assume to always be there
-        displayName = entry.value(KIO::UDSEntry::UDS_NAME).toString();
-
-        // For a field that might not be there
-        auto it = entry.constFind(KIO::UDSEntry::UDS_URL);
-        const auto end = entry.cend();
-        if (it != end) {
-            url = it.value().toString();
-        }
-
-        it = entry.constFind(KIO::UDSEntry::UDS_SIZE);
-        if (it != end) {
-            size = it.value().toULongLong();
-        }
-
-        QCOMPARE(size, 123456ULL);
-        QCOMPARE(displayName, QStringLiteral("name"));
-        QVERIFY(url.isEmpty());
-    }
-}
-
 // The KDE4 solution: QHash+struct
 
 // Which one is used depends on UDS_STRING vs UDS_LONG
@@ -223,113 +85,41 @@ struct UDSAtom4 { // can't be a union due to qstring...
 };
 
 // Another possibility, to save on QVariant costs
-typedef QHash<uint, UDSAtom4> UDSEntryHS; // hash+struct
-
-static void fillQHashStructEntry(UDSEntryHS &entry, time_t now_time_t, const QString &nameStr)
+// hash+struct
+// using QMap is slower
+class UDSEntryHS : public QHash<uint, UDSAtom4>
 {
-    entry.reserve(8);
-    entry.insert(KIO::UDSEntry::UDS_NAME, nameStr);
-    entry.insert(KIO::UDSEntry::UDS_SIZE, 123456ULL);
-    entry.insert(KIO::UDSEntry::UDS_MODIFICATION_TIME, now_time_t);
-    entry.insert(KIO::UDSEntry::UDS_ACCESS_TIME, now_time_t);
-    entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
-    entry.insert(KIO::UDSEntry::UDS_ACCESS, 0644);
-    entry.insert(KIO::UDSEntry::UDS_USER, nameStr);
-    entry.insert(KIO::UDSEntry::UDS_GROUP, nameStr);
-}
-void UdsEntryBenchmark::testHashStructSlave()
-{
-    QBENCHMARK {
-        UDSEntryHS entry;
-        fillQHashStructEntry(entry, now_time_t, nameStr);
-        QCOMPARE(entry.count(), 8);
+public:
+    void replaceOrInsert(uint udsField, const QString &value)
+    {
+        insert(udsField, value);
     }
-}
-
-void UdsEntryBenchmark::testHashStructApp()
-{
-    UDSEntryHS entry;
-    fillQHashStructEntry(entry, now_time_t, nameStr);
-
-    QString displayName;
-    KIO::filesize_t size;
-    QString url;
-
-    QBENCHMARK {
-        // For a field that we assume to always be there
-        displayName = entry.value(KIO::UDSEntry::UDS_NAME).m_str;
-
-        // For a field that might not be there
-        auto it = entry.constFind(KIO::UDSEntry::UDS_URL);
-        const auto end = entry.cend();
-        if (it != end) {
-            url = it.value().m_str;
-        }
-
-        it = entry.constFind(KIO::UDSEntry::UDS_SIZE);
-        if (it != end) {
-            size = it.value().m_long;
-        }
-        QCOMPARE(size, 123456ULL);
-        QCOMPARE(displayName, QStringLiteral("name"));
-        QVERIFY(url.isEmpty());
+    void replaceOrInsert(uint udsField, long long value)
+    {
+        insert(udsField, value);
     }
-}
-
-// Let's see if QMap makes any difference
-typedef QMap<uint, UDSAtom4> UDSEntryMS; // map+struct
-
-static void fillQMapStructEntry(UDSEntryMS &entry, time_t now_time_t, const QString &nameStr)
-{
-    entry.insert(KIO::UDSEntry::UDS_NAME, nameStr);
-    entry.insert(KIO::UDSEntry::UDS_SIZE, 123456ULL);
-    entry.insert(KIO::UDSEntry::UDS_MODIFICATION_TIME, now_time_t);
-    entry.insert(KIO::UDSEntry::UDS_ACCESS_TIME, now_time_t);
-    entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
-    entry.insert(KIO::UDSEntry::UDS_ACCESS, 0644);
-    entry.insert(KIO::UDSEntry::UDS_USER, nameStr);
-    entry.insert(KIO::UDSEntry::UDS_GROUP, nameStr);
-}
-
-void UdsEntryBenchmark::testMapStructSlave()
-{
-    QBENCHMARK {
-        UDSEntryMS entry;
-        fillQMapStructEntry(entry, now_time_t, nameStr);
-        QCOMPARE(entry.count(), 8);
+    int count() const
+    {
+        return size();
     }
-}
-
-void UdsEntryBenchmark::testMapStructApp()
-{
-    UDSEntryMS entry;
-    fillQMapStructEntry(entry, now_time_t, nameStr);
-
-    QString displayName;
-    KIO::filesize_t size;
-    QString url;
-
-    QBENCHMARK {
-        // For a field that we assume to always be there
-        displayName = entry.value(KIO::UDSEntry::UDS_NAME).m_str;
-
-        // For a field that might not be there
-        auto it = entry.constFind(KIO::UDSEntry::UDS_URL);
-        const auto end = entry.cend();
-        if (it != end) {
-            url = it.value().m_str;
-        }
-
-        it = entry.constFind(KIO::UDSEntry::UDS_SIZE);
-        if (it != end) {
-            size = it.value().m_long;
-        }
-
-        QCOMPARE(size, 123456ULL);
-        QCOMPARE(displayName, QStringLiteral("name"));
-        QVERIFY(url.isEmpty());
+    QString stringValue(uint udsField) const
+    {
+        return value(udsField).m_str;
     }
-}
+    long long numberValue(uint udsField, long long defaultValue = -1) const
+    {
+        if (contains(udsField)) {
+            return value(udsField).m_long;
+        }
+        return defaultValue;
+    }
+    QString spaceUsed()
+    {
+        return QStringLiteral("size:%1 space used:%2")
+            .arg(size() * sizeof(UDSAtom4) + sizeof(QHash<uint, UDSAtom4>))
+            .arg(capacity() * sizeof(UDSAtom4) + sizeof(QHash<uint, UDSAtom4>));
+    }
+};
 
 // Frank's suggestion in https://git.reviewboard.kde.org/r/118452/
 class FrankUDSEntry
@@ -350,9 +140,9 @@ public:
         QString m_str;
         long long m_long;
     };
-    QVector<Field> fields;
+    QList<Field> fields;
     // If udsIndexes[i] == uds, then fields[i] contains the value for 'uds'.
-    QVector<uint> udsIndexes;
+    QList<uint> udsIndexes;
 
     void reserve(int size)
     {
@@ -409,89 +199,16 @@ public:
             return defaultValue;
         }
     }
+    QString spaceUsed()
+    {
+        return QStringLiteral("size:%1 space used:%2")
+            .arg(fields.size() * sizeof(Field) + udsIndexes.size() * sizeof(uint) + sizeof(std::vector<Field>) + sizeof(std::vector<uint>))
+            .arg(fields.capacity() * sizeof(Field) + udsIndexes.capacity() * sizeof(uint) + sizeof(std::vector<Field>) + sizeof(std::vector<uint>));
+    }
 };
 
-template<class T>
-static void fillUDSEntries(T &entry, time_t now_time_t, const QString &nameStr)
-{
-    entry.reserve(8);
-    // In random order of index
-    entry.insert(KIO::UDSEntry::UDS_ACCESS_TIME, now_time_t);
-    entry.insert(KIO::UDSEntry::UDS_MODIFICATION_TIME, now_time_t);
-    entry.insert(KIO::UDSEntry::UDS_SIZE, 123456ULL);
-    entry.insert(KIO::UDSEntry::UDS_NAME, nameStr);
-    entry.insert(KIO::UDSEntry::UDS_GROUP, nameStr);
-    entry.insert(KIO::UDSEntry::UDS_USER, nameStr);
-    entry.insert(KIO::UDSEntry::UDS_ACCESS, 0644);
-    entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
-}
-
-template<class T>
-void testFill(time_t now_time_t, const QString &nameStr)
-{
-    QBENCHMARK {
-        T entry;
-        fillUDSEntries<T>(entry, now_time_t, nameStr);
-        QCOMPARE(entry.count(), 8);
-    }
-}
-
-template<class T>
-void testCompare(time_t now_time_t, const QString &nameStr)
-{
-    T entry;
-    T entry2;
-    fillUDSEntries<T>(entry, now_time_t, nameStr);
-    fillUDSEntries<T>(entry2, now_time_t, nameStr);
-    QCOMPARE(entry.count(), 8);
-    QCOMPARE(entry2.count(), 8);
-    QBENCHMARK {
-        bool equal = entry.stringValue(KIO::UDSEntry::UDS_NAME) == entry2.stringValue(KIO::UDSEntry::UDS_NAME)
-            && entry.numberValue(KIO::UDSEntry::UDS_SIZE) == entry2.numberValue(KIO::UDSEntry::UDS_SIZE)
-            && entry.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME) == entry2.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME)
-            && entry.numberValue(KIO::UDSEntry::UDS_ACCESS_TIME) == entry2.numberValue(KIO::UDSEntry::UDS_ACCESS_TIME)
-            && entry.numberValue(KIO::UDSEntry::UDS_FILE_TYPE) == entry2.numberValue(KIO::UDSEntry::UDS_FILE_TYPE)
-            && entry.numberValue(KIO::UDSEntry::UDS_ACCESS) == entry2.numberValue(KIO::UDSEntry::UDS_ACCESS)
-            && entry.stringValue(KIO::UDSEntry::UDS_USER) == entry2.stringValue(KIO::UDSEntry::UDS_USER)
-            && entry.stringValue(KIO::UDSEntry::UDS_GROUP) == entry2.stringValue(KIO::UDSEntry::UDS_GROUP);
-        QVERIFY(equal);
-    }
-}
-
-template<class T>
-void testApp(time_t now_time_t, const QString &nameStr)
-{
-    T entry;
-    fillUDSEntries<T>(entry, now_time_t, nameStr);
-
-    QString displayName;
-    KIO::filesize_t size;
-    QString url;
-
-    QBENCHMARK {
-        displayName = entry.stringValue(KIO::UDSEntry::UDS_NAME);
-        url = entry.stringValue(KIO::UDSEntry::UDS_URL);
-        size = entry.numberValue(KIO::UDSEntry::UDS_SIZE);
-        QCOMPARE(size, 123456ULL);
-        QCOMPARE(displayName, QStringLiteral("name"));
-        QVERIFY(url.isEmpty());
-    }
-}
-
-void UdsEntryBenchmark::testTwoVectorsSlaveFill()
-{
-    testFill<FrankUDSEntry>(now_time_t, nameStr);
-}
-void UdsEntryBenchmark::testTwoVectorsSlaveCompare()
-{
-    testCompare<FrankUDSEntry>(now_time_t, nameStr);
-}
-void UdsEntryBenchmark::testTwoVectorsApp()
-{
-    testApp<FrankUDSEntry>(now_time_t, nameStr);
-}
-
 // Instead of two vectors, use only one
+// KF 5
 class AnotherUDSEntry
 {
 private:
@@ -596,23 +313,16 @@ public:
         }
         return defaultValue;
     }
+    QString spaceUsed()
+    {
+        return QStringLiteral("size:%1 space used:%2")
+            .arg(storage.size() * sizeof(Field) + sizeof(std::vector<Field>))
+            .arg(storage.capacity() * sizeof(Field) + sizeof(std::vector<Field>));
+    }
 };
-Q_DECLARE_TYPEINFO(AnotherUDSEntry, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(AnotherUDSEntry, Q_RELOCATABLE_TYPE);
 
-void UdsEntryBenchmark::testAnotherSlaveFill()
-{
-    testFill<AnotherUDSEntry>(now_time_t, nameStr);
-}
-void UdsEntryBenchmark::testAnotherSlaveCompare()
-{
-    testCompare<AnotherUDSEntry>(now_time_t, nameStr);
-}
-void UdsEntryBenchmark::testAnotherApp()
-{
-    testApp<AnotherUDSEntry>(now_time_t, nameStr);
-}
-
-// Instead of two vectors, use only one sorted by index and accessed using a binary search.
+// Use one vector with binary search
 class AnotherV2UDSEntry
 {
 private:
@@ -658,7 +368,7 @@ public:
         Q_ASSERT(udsField & KIO::UDSEntry::UDS_STRING);
         auto it = std::lower_bound(storage.cbegin(), storage.cend(), udsField, less);
         Q_ASSERT(it == storage.cend() || it->m_index != udsField);
-        storage.insert(it, Field(udsField, value));
+        storage.emplace(it, udsField, value);
     }
     void replaceOrInsert(uint udsField, const QString &value)
     {
@@ -668,14 +378,14 @@ public:
             it->m_str = value;
             return;
         }
-        storage.insert(it, Field(udsField, value));
+        storage.emplace(it, udsField, value);
     }
     void insert(uint udsField, long long value)
     {
         Q_ASSERT(udsField & KIO::UDSEntry::UDS_NUMBER);
         auto it = std::lower_bound(storage.cbegin(), storage.cend(), udsField, less);
         Q_ASSERT(it == storage.end() || it->m_index != udsField);
-        storage.insert(it, Field(udsField, value));
+        storage.emplace(it, udsField, value);
     }
     void replaceOrInsert(uint udsField, long long value)
     {
@@ -685,7 +395,7 @@ public:
             it->m_long = value;
             return;
         }
-        storage.insert(it, Field(udsField, value));
+        storage.emplace(it, udsField, value);
     }
     int count() const
     {
@@ -707,20 +417,302 @@ public:
         }
         return defaultValue;
     }
-};
-Q_DECLARE_TYPEINFO(AnotherV2UDSEntry, Q_MOVABLE_TYPE);
 
-void UdsEntryBenchmark::testAnotherV2SlaveFill()
+    QString spaceUsed()
+    {
+        return QStringLiteral("size:%1 space used:%2")
+            .arg(storage.size() * sizeof(Field) + sizeof(std::vector<Field>))
+            .arg(storage.capacity() * sizeof(Field) + sizeof(std::vector<Field>));
+    }
+};
+Q_DECLARE_TYPEINFO(AnotherV2UDSEntry, Q_RELOCATABLE_TYPE);
+
+// Instead of two vectors, use only one sorted by index and accessed using a binary search.
+class TwoVectorKindEntry
 {
-    testFill<AnotherV2UDSEntry>(now_time_t, nameStr);
+private:
+    struct StringField {
+        inline StringField()
+        {
+        }
+        inline StringField(const uint index, const QString &value)
+            : m_index(index)
+            , m_str(value)
+        {
+        }
+        // This operator helps to gain 1ms just comparing the key
+        inline bool operator==(const StringField &other) const
+        {
+            return m_index == other.m_index;
+        }
+
+        uint m_index = 0;
+        QString m_str;
+    };
+    struct NumberField {
+        inline NumberField()
+        {
+        }
+        inline NumberField(const uint index, long long value = 0)
+            : m_index(index)
+            , m_long(value)
+        {
+        }
+        // This operator helps to gain 1ms just comparing the key
+        inline bool operator==(const NumberField &other) const
+        {
+            return m_index == other.m_index;
+        }
+
+        uint m_index = 0;
+        long long m_long = LLONG_MIN;
+    };
+    std::vector<StringField> stringStorage;
+    std::vector<NumberField> numberStorage;
+
+public:
+    void reserve(int size)
+    {
+        Q_UNUSED(size)
+        // ideal case
+        stringStorage.reserve(3);
+        numberStorage.reserve(5);
+        // stringStorage.reserve(size / 3);
+        // numberStorage.reserve(size * 2 / 3);
+    }
+    void insert(uint udsField, const QString &value)
+    {
+        Q_ASSERT(udsField & KIO::UDSEntry::UDS_STRING);
+        stringStorage.emplace_back(udsField, value);
+    }
+    void replaceOrInsert(uint udsField, const QString &value)
+    {
+        Q_ASSERT(udsField & KIO::UDSEntry::UDS_STRING);
+        auto it = std::find_if(stringStorage.begin(), stringStorage.end(), [udsField](const StringField &field) {
+            return field.m_index == udsField;
+        });
+        if (it != stringStorage.end()) {
+            it->m_str = value;
+            return;
+        }
+        stringStorage.emplace(it, udsField, value);
+    }
+    QString stringValue(uint udsField) const
+    {
+        Q_ASSERT(udsField & KIO::UDSEntry::UDS_STRING);
+        auto it = std::find_if(stringStorage.cbegin(), stringStorage.cend(), [udsField](const StringField &field) {
+            return field.m_index == udsField;
+        });
+        if (it != stringStorage.end()) {
+            return it->m_str;
+        }
+        return QString();
+    }
+    void insert(uint udsField, long long value)
+    {
+        Q_ASSERT(udsField & KIO::UDSEntry::UDS_NUMBER);
+        numberStorage.emplace_back(udsField, value);
+    }
+    void replaceOrInsert(uint udsField, long long value)
+    {
+        Q_ASSERT(udsField & KIO::UDSEntry::UDS_NUMBER);
+        auto it = std::find_if(numberStorage.begin(), numberStorage.end(), [udsField](const NumberField &field) {
+            return field.m_index == udsField;
+        });
+        if (it != numberStorage.end()) {
+            it->m_long = value;
+            return;
+        }
+        numberStorage.emplace(it, udsField, value);
+    }
+    long long numberValue(uint udsField, long long defaultValue = -1) const
+    {
+        Q_ASSERT(udsField & KIO::UDSEntry::UDS_NUMBER);
+        auto it = std::find_if(numberStorage.cbegin(), numberStorage.cend(), [udsField](const NumberField &field) {
+            return field.m_index == udsField;
+        });
+        if (it != numberStorage.end()) {
+            return it->m_long;
+        }
+        return defaultValue;
+    }
+
+    int count() const
+    {
+        return stringStorage.size() + numberStorage.size();
+    }
+
+    QString spaceUsed()
+    {
+        return QStringLiteral("size:%1 space used:%2")
+            .arg(stringStorage.size() * sizeof(StringField) + sizeof(std::vector<StringField>) + sizeof(std::vector<NumberField>)
+                 + numberStorage.size() * sizeof(NumberField))
+            .arg(sizeof(std::vector<StringField>) + sizeof(std::vector<NumberField>) + stringStorage.capacity() * sizeof(StringField)
+                 + numberStorage.capacity() * sizeof(NumberField));
+    }
+};
+Q_DECLARE_TYPEINFO(TwoVectorKindEntry, Q_MOVABLE_TYPE);
+
+template<class T>
+static void fillUDSEntries(T &entry, time_t now_time_t, const QString &nameStr, const QString &groupStr)
+{
+    entry.reserve(8);
+    // In random order of index
+    entry.insert(KIO::UDSEntry::UDS_ACCESS_TIME, now_time_t);
+    entry.insert(KIO::UDSEntry::UDS_MODIFICATION_TIME, now_time_t);
+    entry.insert(KIO::UDSEntry::UDS_SIZE, 123456ULL);
+    entry.insert(KIO::UDSEntry::UDS_NAME, nameStr);
+    entry.insert(KIO::UDSEntry::UDS_GROUP, groupStr);
+    entry.insert(KIO::UDSEntry::UDS_USER, nameStr);
+    entry.insert(KIO::UDSEntry::UDS_ACCESS, 0644);
+    entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
 }
-void UdsEntryBenchmark::testAnotherV2SlaveCompare()
+
+template<class T>
+void testFill(UdsEntryBenchmark *bench)
 {
-    testCompare<AnotherV2UDSEntry>(now_time_t, nameStr);
+    // test fill, aka append to container efficiency
+    QBENCHMARK {
+        T entry;
+        fillUDSEntries<T>(entry, bench->now_time_t, bench->nameStr, bench->groupStr);
+    }
+}
+
+template<class T>
+void testCompare(UdsEntryBenchmark *bench)
+{
+    // heavy read test, aka container access efficiency
+    T entry;
+    T entry2;
+    fillUDSEntries<T>(entry, bench->now_time_t, bench->nameStr, bench->groupStr);
+    fillUDSEntries<T>(entry2, bench->now_time_t, bench->nameStr, bench->groupStr);
+    QCOMPARE(entry.count(), 8);
+    QCOMPARE(entry2.count(), 8);
+    QBENCHMARK {
+        bool equal = entry.stringValue(KIO::UDSEntry::UDS_NAME) == entry2.stringValue(KIO::UDSEntry::UDS_NAME)
+            && entry.numberValue(KIO::UDSEntry::UDS_SIZE) == entry2.numberValue(KIO::UDSEntry::UDS_SIZE)
+            && entry.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME) == entry2.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME)
+            && entry.numberValue(KIO::UDSEntry::UDS_ACCESS_TIME) == entry2.numberValue(KIO::UDSEntry::UDS_ACCESS_TIME)
+            && entry.numberValue(KIO::UDSEntry::UDS_FILE_TYPE) == entry2.numberValue(KIO::UDSEntry::UDS_FILE_TYPE)
+            && entry.numberValue(KIO::UDSEntry::UDS_ACCESS) == entry2.numberValue(KIO::UDSEntry::UDS_ACCESS)
+            && entry.stringValue(KIO::UDSEntry::UDS_USER) == entry2.stringValue(KIO::UDSEntry::UDS_USER)
+            && entry.stringValue(KIO::UDSEntry::UDS_GROUP) == entry2.stringValue(KIO::UDSEntry::UDS_GROUP);
+        QVERIFY(equal);
+    }
+}
+
+template<class T>
+void testApp(UdsEntryBenchmark *bench)
+{
+    // test fill + entry read
+
+    QString displayName;
+    KIO::filesize_t size;
+    int access;
+    QString url;
+
+    QBENCHMARK {
+        T entry;
+        fillUDSEntries<T>(entry, bench->now_time_t, bench->nameStr, bench->groupStr);
+
+        // random field access
+        displayName = entry.stringValue(KIO::UDSEntry::UDS_NAME);
+        url = entry.stringValue(KIO::UDSEntry::UDS_URL);
+        size = entry.numberValue(KIO::UDSEntry::UDS_SIZE);
+        access = entry.numberValue(KIO::UDSEntry::UDS_ACCESS);
+        QCOMPARE(size, 123456ULL);
+        QCOMPARE(access, 0644);
+        QCOMPARE(displayName, QStringLiteral("name"));
+        QVERIFY(url.isEmpty());
+    }
+}
+
+template<class T>
+void testStruct(UdsEntryBenchmark *bench)
+{
+    testFill<T>(bench);
+    testCompare<T>(bench);
+    testApp<T>(bench);
+}
+
+void UdsEntryBenchmark::testAnotherFill()
+{
+    testFill<AnotherUDSEntry>(this);
+}
+void UdsEntryBenchmark::testTwoVectorKindEntryFill()
+{
+    testFill<TwoVectorKindEntry>(this);
+}
+void UdsEntryBenchmark::testAnotherV2Fill()
+{
+    testFill<AnotherV2UDSEntry>(this);
+}
+void UdsEntryBenchmark::testTwoVectorsFill()
+{
+    testFill<FrankUDSEntry>(this);
+}
+void UdsEntryBenchmark::testUDSEntryHSFill()
+{
+    testFill<UDSEntryHS>(this);
+}
+
+void UdsEntryBenchmark::testAnotherCompare()
+{
+    testCompare<AnotherUDSEntry>(this);
+}
+void UdsEntryBenchmark::testAnotherV2Compare()
+{
+    testCompare<AnotherV2UDSEntry>(this);
+}
+void UdsEntryBenchmark::testTwoVectorKindEntryCompare()
+{
+    testCompare<TwoVectorKindEntry>(this);
+}
+void UdsEntryBenchmark::testTwoVectorsCompare()
+{
+    testCompare<FrankUDSEntry>(this);
+}
+void UdsEntryBenchmark::testUDSEntryHSCompare()
+{
+    testCompare<UDSEntryHS>(this);
+}
+
+void UdsEntryBenchmark::testTwoVectorKindEntryApp()
+{
+    testApp<TwoVectorKindEntry>(this);
+}
+void UdsEntryBenchmark::testAnotherApp()
+{
+    testApp<AnotherUDSEntry>(this);
 }
 void UdsEntryBenchmark::testAnotherV2App()
 {
-    testApp<AnotherV2UDSEntry>(now_time_t, nameStr);
+    testApp<AnotherV2UDSEntry>(this);
+}
+void UdsEntryBenchmark::testTwoVectorsApp()
+{
+    testApp<FrankUDSEntry>(this);
+}
+void UdsEntryBenchmark::testUDSEntryHSApp()
+{
+    testApp<UDSEntryHS>(this);
+}
+
+template<class T>
+void printSpaceUsed(UdsEntryBenchmark *bench)
+{
+    T entry;
+    fillUDSEntries<T>(entry, bench->now_time_t, bench->nameStr, bench->groupStr);
+    qDebug() << typeid(T).name() << " memory used" << entry.spaceUsed();
+}
+
+void UdsEntryBenchmark::testspaceUsed()
+{
+    printSpaceUsed<FrankUDSEntry>(this);
+    printSpaceUsed<AnotherUDSEntry>(this);
+    printSpaceUsed<AnotherV2UDSEntry>(this);
+    printSpaceUsed<TwoVectorKindEntry>(this);
+    printSpaceUsed<UDSEntryHS>(this);
 }
 
 QTEST_MAIN(UdsEntryBenchmark)
