@@ -14,10 +14,11 @@
 #include <QMetaType>
 #include <QStringList>
 
-/**
- * \class KProtocolInfo kprotocolinfo.h <KProtocolInfo>
+/*!
+ * \class KProtocolInfo
+ * \inmodule KIOCore
  *
- * Information about I/O (Internet, etc.) protocols supported by KDE.
+ * \brief Information about I/O (Internet, etc.) protocols supported by KDE.
 
  * KProtocolInfo is useful if you want to know which protocols
  * KDE supports. In addition you can find out lots of information
@@ -37,55 +38,58 @@ public:
     // Static functions:
     //
 
-    /**
+    /*!
      * Returns list of all known protocols.
-     * @return a list of all known protocols
      */
     static QStringList protocols();
 
-    /**
-     * Returns whether a protocol is installed that is able to handle @p url.
+    /*!
+     * Returns whether a protocol is installed that is able to handle \a url.
      *
-     * @param url the url to check
-     * @return true if the protocol is known
-     * @see name()
+     * \a url the url to check
      */
     static bool isKnownProtocol(const QUrl &url);
 
-    /**
+    /*!
      * Same as above except you can supply just the protocol instead of
      * the whole URL.
      */
     static bool isKnownProtocol(const QString &protocol, bool updateCacheIfNotfound = true);
 
-    /**
-     * Returns the library / executable to open for the protocol @p protocol
+    /*!
+     * Returns the library / executable to open for the protocol \a protocol
      * Example : "kio_ftp", meaning either the executable "kio_ftp" or
      * the library "kio_ftp.la" (recommended), whichever is available.
      *
      * This corresponds to the "exec=" field in the protocol description file.
-     * @param protocol the protocol to check
-     * @return the executable of library to open, or QString() for
+     *
+     * \a protocol the protocol to check
+     *
+     * Returns the executable of library to open, or QString() for
      *         unsupported protocols
-     * @see KUrl::protocol()
      */
     static QString exec(const QString &protocol);
 
-    /**
+    /*!
      * Describes the type of a protocol.
      * For instance ftp:// appears as a filesystem with folders and files,
      * while bzip2:// appears as a single file (a stream of data),
      * and telnet:// doesn't output anything.
-     * @see outputType
+     *
+     * \value T_STREAM stream of data (e.g.\ single file)
+     * \value T_FILESYSTEM structured directory
+     * \value T_NONE no information about the type available
+     * \value T_ERROR used to signal an error
      */
     enum Type {
-        T_STREAM, ///< stream of data (e.g.\ single file)
-        T_FILESYSTEM, ///< structured directory
-        T_NONE, ///< no information about the type available
-        T_ERROR, ///< used to signal an error
+        T_STREAM,
+        T_FILESYSTEM,
+        T_NONE,
+        T_ERROR,
     };
 
-    /**
+    /*!
+     * \inmodule KIOCore
      * Definition of an extra field in the UDS entries, returned by a listDir operation.
      *
      * The name is the name of the column, translated.
@@ -94,7 +98,16 @@ public:
      * Currently supported types: "QString", "QDateTime" (ISO-8601 format)
      */
     struct ExtraField {
-        enum Type { String = QMetaType::QString, DateTime = QMetaType::QDateTime, Invalid = QMetaType::UnknownType };
+        /*!
+         * \value String
+         * \value DateTime
+         * \value Invalid
+         */
+        enum Type {
+            String = QMetaType::QString,
+            DateTime = QMetaType::QDateTime,
+            Invalid = QMetaType::UnknownType
+        };
 
         ExtraField()
             : type(Invalid)
@@ -108,8 +121,11 @@ public:
         QString name;
         Type type;
     };
+    /*!
+     * TODO qdoc?
+     */
     typedef QList<ExtraField> ExtraFieldList;
-    /**
+    /*!
      * Definition of extra fields in the UDS entries, returned by a listDir operation.
      *
      * This corresponds to the "ExtraNames=" and "ExtraTypes=" fields in the protocol description file.
@@ -118,7 +134,7 @@ public:
      */
     static ExtraFieldList extraFields(const QUrl &url);
 
-    /**
+    /*!
      * Returns whether the protocol can act as a helper protocol.
      * A helper protocol invokes an external application and does not return
      * a file or stream.
@@ -126,19 +142,20 @@ public:
      * This corresponds to the "helper=" field in the protocol description file.
      * Valid values for this field are "true" or "false" (default).
      *
-     * @param url the url to check
-     * @return true if the protocol is a helper protocol (e.g. vnc), false
+     * \a url the url to check
+     *
+     * Returns \c true if the protocol is a helper protocol (e.g. vnc), false
      *              if not (e.g. http)
      */
     static bool isHelperProtocol(const QUrl &url);
 
-    /**
+    /*!
      * Same as above except you can supply just the protocol instead of
      * the whole URL.
      */
     static bool isHelperProtocol(const QString &protocol);
 
-    /**
+    /*!
      * Returns whether the protocol can act as a filter protocol.
      *
      * A filter protocol can operate on data that is passed to it
@@ -150,42 +167,44 @@ public:
      * Valid values for this field are "true" (default) for source protocol or
      * "false" for filter protocol.
      *
-     * @param url the url to check
-     * @return true if the protocol is a filter (e.g. gzip), false if the
+     * \a url the url to check
+     *
+     * Returns \c true if the protocol is a filter (e.g. gzip), false if the
      *         protocol is a helper or source
      */
     static bool isFilterProtocol(const QUrl &url);
 
-    /**
+    /*!
      * Same as above except you can supply just the protocol instead of
      * the whole URL.
      */
     static bool isFilterProtocol(const QString &protocol);
 
-    /**
+    /*!
      * Returns the name of the icon, associated with the specified protocol.
      *
      * This corresponds to the "Icon=" field in the protocol description file.
      *
-     * @param protocol the protocol to check
-     * @return the icon of the protocol, or an empty string if unknown
+     * \a protocol the protocol to check
+     *
+     * Returns the icon of the protocol, or an empty string if unknown
      */
     static QString icon(const QString &protocol);
 
-    /**
+    /*!
      * Returns the name of the config file associated with the
      * specified protocol. This is useful if two similar protocols
      * need to share a single config file, e.g. http and https.
      *
      * This corresponds to the "config=" field in the protocol description file.
-     * The default is the protocol name, see name()
      *
-     * @param protocol the protocol to check
-     * @return the config file, or an empty string if unknown
+     * \a protocol the protocol to check
+     *
+     * Returns the config file, or an empty string if unknown
      */
     static QString config(const QString &protocol);
 
-    /**
+    /*!
      * Returns the soft limit on the number of KIO workers for this protocol.
      * This limits the number of workers used for a single operation, note
      * that multiple operations may result in a number of instances that
@@ -194,27 +213,29 @@ public:
      * This corresponds to the "maxInstances=" field in the protocol's worker metadata.
      * The default is 1.
      *
-     * @param protocol the protocol to check
-     * @return the maximum number of workers, or 1 if unknown
+     * \a protocol the protocol to check
      *
-     * @since 5.101
+     * Returns the maximum number of workers, or 1 if unknown
+     *
+     * \since 5.101
      */
     static int maxWorkers(const QString &protocol);
 
-    /**
+    /*!
      * Returns the limit on the number of KIO workers for this protocol per host.
      *
      * This corresponds to the "maxInstancesPerHost=" field in the protocol's worker metadata.
      * The default is 0 which means there is no per host limit.
      *
-     * @param protocol the protocol to check
-     * @return the maximum number of workers, or 1 if unknown
+     * \a protocol the protocol to check
      *
-     * @since 5.101
+     * Returns the maximum number of workers, or 1 if unknown
+     *
+     * \since 5.101
      */
     static int maxWorkersPerHost(const QString &protocol);
 
-    /**
+    /*!
      * Returns whether MIME types can be determined based on extension for this
      * protocol. For some protocols, e.g. http, the filename extension in the URL
      * can not be trusted to truly reflect the file type.
@@ -222,62 +243,69 @@ public:
      * This corresponds to the "determineMimetypeFromExtension=" field in the protocol description file.
      * Valid values for this field are "true" (default) or "false".
      *
-     * @param protocol the protocol to check
-     * @return true if the MIME types can be determined by extension
+     * \a protocol the protocol to check
+     *
+     * Returns \c true if the MIME types can be determined by extension
      */
     static bool determineMimetypeFromExtension(const QString &protocol);
 
-    /**
+    /*!
      * Returns the default MIME type for the specified protocol, if one exists.
      *
      * This corresponds to the "defaultMimetype=" field in the protocol description file.
      *
-     * @param protocol the protocol to check
-     * @return the default MIME type of the protocol, or an empty string if none set or protocol unknown
-     * @since 5.60
+     * \a protocol the protocol to check
+     *
+     * Returns the default MIME type of the protocol, or an empty string if none set or protocol unknown
+     * \since 5.60
      */
     static QString defaultMimetype(const QString &protocol);
 
-    /**
+    /*!
      * Returns the documentation path for the specified protocol.
      *
      * This corresponds to the "X-DocPath=" or "DocPath=" field in the protocol description file.
      *
-     * @param protocol the protocol to check
-     * @return the docpath of the protocol, or an empty string if unknown
+     * \a protocol the protocol to check
+     *
+     * Returns the docpath of the protocol, or an empty string if unknown
      */
     static QString docPath(const QString &protocol);
 
-    /**
+    /*!
      * Returns the protocol class for the specified protocol.
      *
      * This corresponds to the "Class=" field in the protocol description file.
      *
      * The following classes are defined:
-     * @li ":internet" for common internet protocols
-     * @li ":local" for protocols that access local resources
+     * \list
+     * \li ":internet" for common internet protocols
+     * \li ":local" for protocols that access local resources
+     * \endlist
      *
      * Protocol classes always start with a ':' so that they can not be confused with
      * the protocols themselves.
      *
-     * @param protocol the protocol to check
-     * @return the class of the protocol, or an empty string if unknown
+     * \a protocol the protocol to check
+     *
+     * Returns the class of the protocol, or an empty string if unknown
      */
     static QString protocolClass(const QString &protocol);
 
-    /**
+    /*!
      * Returns whether file previews should be shown for the specified protocol.
      *
      * This corresponds to the "ShowPreviews=" field in the protocol description file.
      *
      * By default previews are shown if protocolClass is :local.
      *
-     * @param protocol the protocol to check
-     * @return true if previews should be shown by default, false otherwise
+     * \a protocol the protocol to check
+     *
+     * Returns \c true if previews should be shown by default, false otherwise
      */
     static bool showFilePreview(const QString &protocol);
 
-    /**
+    /*!
      * Returns the list of capabilities provided by the KIO worker implementing
      * this protocol.
      *
@@ -290,24 +318,27 @@ public:
      * before sending a special() command that would otherwise do nothing
      * on older KIO worker implementations.
      *
-     * @param protocol the protocol to check
-     * @return the list of capabilities.
+     * \a protocol the protocol to check
+     *
+     * Returns the list of capabilities.
      */
     static QStringList capabilities(const QString &protocol);
 
-    /**
+    /*!
      * Returns the list of archive MIME types handled by the KIO worker implementing
      * this protocol.
      *
      * This corresponds to the "archiveMimetype=" field in the protocol description file.
      *
-     * @param protocol the protocol to check
-     * @return the list of archive MIME types (e.g. application/x-zip) handled.
-     * @since 5.23
+     * \a protocol the protocol to check
+     *
+     * Returns the list of archive MIME types (e.g. application/x-zip) handled.
+     * \since 5.23
      */
     static QStringList archiveMimetypes(const QString &protocol);
 
-    /**
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(6, 4)
+    /*!
      * Returns the name of the protocol through which the request
      * will be routed if proxy support is enabled.
      *
@@ -315,10 +346,20 @@ public:
      * support is commonly handled by the http protocol.
      *
      * This corresponds to the "ProxiedBy=" in the protocol description file.
+     *
+     * Not used.
+     *
+     * \deprecated[6.4]
      */
+    KIOCORE_DEPRECATED_VERSION(6, 4, "Not used")
     static QString proxiedBy(const QString &protocol);
+#endif
 
-    typedef enum { Name, FromUrl, DisplayName } FileNameUsedForCopying;
+    typedef enum {
+        Name,
+        FromUrl,
+        DisplayName
+    } FileNameUsedForCopying;
 
 private:
     Q_DISABLE_COPY(KProtocolInfo)
