@@ -7,7 +7,6 @@
 
 #include "ksslerroruidata.h"
 #include "ksslerroruidata_p.h"
-#include "ktcpsocket.h"
 
 #include <QHostAddress>
 #include <QNetworkReply>
@@ -20,34 +19,11 @@ KSslErrorUiData::KSslErrorUiData()
     d->bits = 0;
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 65)
-KSslErrorUiData::KSslErrorUiData(const KTcpSocket *socket)
-    : d(new Private())
-{
-    d->certificateChain = socket->peerCertificateChain();
-    const auto ksslErrors = socket->sslErrors();
-    d->sslErrors.reserve(ksslErrors.size());
-    for (const auto &error : ksslErrors) {
-        d->sslErrors.push_back(error.sslError());
-    }
-    d->ip = socket->peerAddress().toString();
-    d->host = socket->peerName();
-    d->sslProtocol = socket->negotiatedSslVersionName();
-    d->cipher = socket->sessionCipher().name();
-    d->usedBits = socket->sessionCipher().usedBits();
-    d->bits = socket->sessionCipher().supportedBits();
-}
-#endif
-
 KSslErrorUiData::KSslErrorUiData(const QSslSocket *socket)
     : d(new Private())
 {
     d->certificateChain = socket->peerCertificateChain();
-#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-    d->sslErrors = socket->sslErrors();
-#else
     d->sslErrors = socket->sslHandshakeErrors();
-#endif
     d->ip = socket->peerAddress().toString();
     d->host = socket->peerName();
     if (socket->isEncrypted()) {
@@ -76,10 +52,7 @@ KSslErrorUiData::KSslErrorUiData(const KSslErrorUiData &other)
 {
 }
 
-KSslErrorUiData::~KSslErrorUiData()
-{
-    delete d;
-}
+KSslErrorUiData::~KSslErrorUiData() = default;
 
 KSslErrorUiData &KSslErrorUiData::operator=(const KSslErrorUiData &other)
 {
