@@ -9,14 +9,11 @@
 
 #include "commands_p.h"
 #include "connection_p.h"
-#include "hostinfo.h"
 #include "kiocoredebug.h"
 #include "usernotificationhandler_p.h"
 #include "workerbase.h"
 
 #include <KLocalizedString>
-#include <signal.h>
-#include <time.h>
 
 #include <QDataStream>
 #include <QDateTime>
@@ -109,7 +106,6 @@ bool WorkerInterface::dispatch(int _cmd, const QByteArray &rawdata)
 
     QString str1;
     qint32 i;
-    qint8 b;
     quint32 ul;
 
     switch (_cmd) {
@@ -160,13 +156,6 @@ bool WorkerInterface::dispatch(int _cmd, const QByteArray &rawdata)
         // qDebug() << "error " << i << " " << str1;
         Q_EMIT error(i, str1);
         break;
-    case MSG_WORKER_STATUS: {
-        qint64 pid;
-        QByteArray protocol;
-        stream >> pid >> protocol >> str1 >> b;
-        Q_EMIT workerStatus(pid, protocol, str1, (b != 0));
-        break;
-    }
     case MSG_CONNECTED:
         Q_EMIT connected();
         break;
@@ -268,12 +257,6 @@ bool WorkerInterface::dispatch(int _cmd, const QByteArray &rawdata)
         Q_EMIT metaData(m);
         break;
     }
-    case MSG_HOST_INFO_REQ: {
-        QString hostName;
-        stream >> hostName;
-        HostInfo::lookupHost(hostName, this, SLOT(slotHostInfo(QHostInfo)));
-        break;
-    }
     case MSG_PRIVILEGE_EXEC:
         Q_EMIT privilegeOperationRequested();
         break;
@@ -376,12 +359,4 @@ void WorkerInterface::messageBox(int type,
     globalUserNotificationHandler()->requestMessageBox(this, type, data);
 }
 
-void WorkerInterface::slotHostInfo(const QHostInfo &info)
-{
-    QByteArray data;
-    QDataStream stream(&data, QIODevice::WriteOnly);
-    stream << info.hostName() << info.addresses() << info.error() << info.errorString();
-    m_connection->send(CMD_HOST_INFO, data);
-}
-
 #include "moc_workerinterface_p.cpp"
