@@ -914,7 +914,8 @@ QUrl KNewFileMenuPrivate::mostLocalUrl(const QUrl &url)
 
 void KNewFileMenuPrivate::slotAbortDialog()
 {
-    m_text = QString();
+    m_text.clear();
+
     if (m_creatingDirectory) {
         Q_EMIT q->directoryCreationRejected(m_baseUrl);
     } else {
@@ -1006,12 +1007,11 @@ void KNewFileMenuPrivate::slotCreateDirectory()
     job->uiDelegate()->setAutoErrorHandlingEnabled(true);
     KJobWidgets::setWindow(job, m_parentWidget);
 
-    if (job) {
-        // We want the error handling to be done by slotResult so that subclasses can reimplement it
-        job->uiDelegate()->setAutoErrorHandlingEnabled(false);
-        QObject::connect(job, &KJob::result, q, &KNewFileMenu::slotResult);
-    }
-    slotAbortDialog();
+    // We want the error handling to be done by slotResult so that subclasses can reimplement it
+    job->uiDelegate()->setAutoErrorHandlingEnabled(false);
+    QObject::connect(job, &KJob::result, q, &KNewFileMenu::slotResult);
+
+    m_text.clear();
 }
 
 static QStringList getInstalledTemplates()
@@ -1180,7 +1180,7 @@ void KNewFileMenuPrivate::slotRealFileOrDir()
         m_text.chop(1);
     }
     m_copyData.m_chosenFileName = m_text;
-    slotAbortDialog();
+    m_text.clear();
     executeStrategy();
 }
 
@@ -1253,11 +1253,15 @@ void KNewFileMenuPrivate::_k_slotTextChanged(const QString &text)
             if (folders.count() > 1) {
                 label = i18n("Using slashes in folder names will create sub-folders, like so:");
                 QString indentation = QString();
+                int i = 0;
                 for (const QString &folder : std::as_const(folders)) {
                     label.append(QLatin1Char('\n'));
                     label.append(indentation);
                     label.append(folder);
-                    label.append(QStringLiteral("/"));
+                    i++;
+                    if (folders.count() != i) {
+                        label.append(QStringLiteral("/"));
+                    }
                     indentation.append(QStringLiteral("    "));
                 }
             } else {
@@ -1288,7 +1292,8 @@ void KNewFileMenuPrivate::_k_slotTextChanged(const QString &text)
     // Using a tilde to begin a file or folder name is not recommended
     else if (text.startsWith(QLatin1Char('~'))) {
 #ifndef Q_OS_WIN
-        if (KShell::tildeExpand(text).startsWith(QStringLiteral("/home/")) && text.length() > 1) {
+        const bool wasExpanded = !KShell::tildeExpand(text).startsWith(QStringLiteral("~"));
+        if (wasExpanded && text.length() > 1) {
             m_messageWidget->setText(
                 xi18nc("@error",
                        "Creating a file or folder with the name <filename>%1</filename> is not possible since it would overlap with the location of a user's home folder.",
@@ -1569,6 +1574,7 @@ void KNewFileMenuPrivate::showNewDirNameDlg(const QString &name)
     m_label->setText(i18n("Create new folder in %1:", m_baseUrl.toDisplayString(QUrl::PreferLocalFile | QUrl::StripTrailingSlash)));
 
     m_lineEdit->setText(name);
+    m_lineEdit->setPlaceholderText(i18nc("@info:placeholder", "Enter folder name"));
 
     const QString defaultFolderIconName = QStringLiteral("inode-directory");
     setIcon(QIcon::fromTheme(defaultFolderIconName));
@@ -1617,6 +1623,8 @@ void KNewFileMenuPrivate::showNewDirNameDlg(const QString &name)
 
         icons.prepend(defaultFolderIconName);
 
+        QWidget *lastWidget = m_chooseIconBox;
+
         for (const QString &icon : icons) {
             const bool isFirstButton = (x == 0 && y == 0);
 
@@ -1633,6 +1641,9 @@ void KNewFileMenuPrivate::showNewDirNameDlg(const QString &name)
             button->setToolButtonStyle(Qt::ToolButtonIconOnly);
             button->setIconSize(QSize(KIconLoader::SizeMedium, KIconLoader::SizeMedium));
 
+            QWidget::setTabOrder(lastWidget, button);
+            lastWidget = button;
+
             m_folderIconGrid->addWidget(button, y, x++);
             if (x == icons.size() / 2) {
                 x = 0;
@@ -1640,7 +1651,7 @@ void KNewFileMenuPrivate::showNewDirNameDlg(const QString &name)
             }
         }
 
-        // TODO fix tab order...
+        QWidget::setTabOrder(lastWidget, m_chooseIconButton);
 
         QObject::connect(m_iconGroup, &QActionGroup::triggered, q, [this](QAction *action) {
             setIcon(action->icon());
