@@ -151,7 +151,7 @@ void HTTPProtocol::handleSslErrors(QNetworkReply *reply, const QList<QSslError>
 
     const QList<QSslError> fatalErrors = KSslCertificateManager::nonIgnorableErrors(sslErrors);
     if (!fatalErrors.isEmpty()) {
-        qCWarning(KIOHTTP_LOG) << "SSL errors that cannot be ignored occured" << fatalErrors;
+        qCWarning(KIOHTTP_LOG) << "SSL errors that cannot be ignored occurred" << fatalErrors;
         Q_EMIT errorOut(KIO::ERR_CANNOT_CONNECT);
         return;
     }
@@ -461,6 +461,9 @@ HTTPProtocol::Response HTTPProtocol::makeRequest(const QUrl &url,
     }
 
     QNetworkReply *reply = nam.sendCustomRequest(request, methodToString(method), inputData);
+    const auto replyDeleter = qScopeGuard([reply] {
+        reply->deleteLater();
+    });
 
     bool mimeTypeEmitted = false;
 
@@ -492,7 +495,17 @@ HTTPProtocol::Response HTTPProtocol::makeRequest(const QUrl &url,
 
         if (statusCode >= 300 && statusCode < 400) {
             const QString redir = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toString();
-            const QUrl newUrl = url.resolved(QUrl(redir));
+            QUrl newUrl = url.resolved(QUrl(redir));
+
+            // Restore the old protocol (http, webdav or dav) after the redirection, but with the correct encryption status
+            bool upgradeToSecure = !url.scheme().endsWith(QLatin1Char('s')) && newUrl.scheme().endsWith(QLatin1Char('s'));
+            bool downgradeToInsecure = url.scheme().endsWith(QLatin1Char('s')) && !newUrl.scheme().endsWith(QLatin1Char('s'));
+            if (upgradeToSecure)
+                newUrl.setScheme(url.scheme() + QLatin1Char('s'));
+            else if (downgradeToInsecure)
+                newUrl.setScheme(url.scheme().chopped(1));
+            else
+                newUrl.setScheme(url.scheme());
 
             // Handled after returning from the event loop.
             // 301 is necessary for Apache (see bugs 209508 and 187970).
@@ -580,8 +593,28 @@ HTTPProtocol::Response HTTPProtocol::makeRequest(const QUrl &url,
         data(QByteArray());
     });
 
+    const int statusCode = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
+    if (reply->error() != QNetworkReply::NoError && statusCode == 0) {
+        // anything not listed here gets KIO::ERR_CANNOT_CONNECT
+        static constexpr const std::pair<QNetworkReply::NetworkError, int> qnam2kio_errors[] = {
+            {QNetworkReply::HostNotFoundError, KIO::ERR_UNKNOWN_HOST},
+            {QNetworkReply::TimeoutError, KIO::ERR_SERVER_TIMEOUT},
+            {QNetworkReply::OperationCanceledError, KIO::ERR_USER_CANCELED},
+            {QNetworkReply::TemporaryNetworkFailureError, KIO::ERR_CONNECTION_BROKEN},
+            {QNetworkReply::NetworkSessionFailedError, KIO::ERR_CONNECTION_BROKEN},
+            {QNetworkReply::ProxyConnectionClosedError, KIO::ERR_CONNECTION_BROKEN},
+            {QNetworkReply::ProxyNotFoundError, KIO::ERR_UNKNOWN_PROXY_HOST},
+            {QNetworkReply::ProxyTimeoutError, KIO::ERR_SERVER_TIMEOUT},
+            {QNetworkReply::ProtocolUnknownError, KIO::ERR_UNSUPPORTED_PROTOCOL},
+        };
+
+        const auto it = std::ranges::find_if(qnam2kio_errors, [reply](const auto &m) {
+            return m.first == reply->error();
+        });
+
+        return {0, QByteArray(), it != std::end(qnam2kio_errors) ? (*it).second : KIO::ERR_CANNOT_CONNECT};
+    }
     if (reply->error() == QNetworkReply::AuthenticationRequiredError) {
-        reply->deleteLater();
         return {0, QByteArray(), KIO::ERR_ACCESS_DENIED};
     }
 
@@ -602,13 +635,9 @@ HTTPProtocol::Response HTTPProtocol::makeRequest(const QUrl &url,
         returnData = reply->readAll();
     }
 
-    int statusCode = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
-
     setMetaData(QStringLiteral("responsecode"), QString::number(statusCode));
     setMetaData(QStringLiteral("content-type"), readMimeType(reply));
 
-    reply->deleteLater();
-
     return {statusCode, returnData};
 }
 
@@ -776,13 +805,9 @@ KIO::WorkerResult HTTPProtocol::davStatList(const QUrl &url, bool stat)
 
     Response response = makeDavRequest(url, method, inputData, DataMode::Return, extraHeaders);
 
-    // Has a redirection already been called? If so, we're done.
-    // if (m_isRedirection || m_kioError) {
-    // if (m_isRedirection) {
-    // return davFinished();
-    // }
-    // return WorkerResult::pass();
-    // }
+    // If this is a redirection we don't have anything to do
+    if (response.httpCode >= 300 && response.httpCode < 400)
+        return KIO::WorkerResult::pass();
 
     QDomDocument multiResponse;
     multiResponse.setContent(response.data, QDomDocument::ParseOption::UseNamespaceProcessing);
@@ -1632,13 +1657,12 @@ static int httpPutError(const QUrl &url, int responseCode, QString *errorString)
 
 KIO::WorkerResult HTTPProtocol::sendHttpError(const QUrl &url, KIO::HTTP_METHOD method, const HTTPProtocol::Response &response)
 {
-    QString errorString;
-    int errorCode = 0;
-
-    if (response.kioCode == KIO::ERR_ACCESS_DENIED) {
+    if (response.kioCode != KJob::NoError) {
         return KIO::WorkerResult::fail(response.kioCode, url.toDisplayString());
     }
 
+    QString errorString;
+    int errorCode = KJob::NoError;
     int responseCode = response.httpCode;
 
     if (method == KIO::HTTP_PUT) {
